Debugging
:::::::::
.. toctree::
   :caption: Debugging
   :maxdepth: 2

   intro-DebuggingGeneral.rst
   intro-HowtobeaSuccessfulProgrammer.rst
   BeginningtipsforDebugging.rst
   Syntaxerrors.rst
   RuntimeErrors.rst
   SemanticErrors.rst
   KnowyourerrorMessages.rst
   Exercises.rst
   